==> qtjambi-webenginecore-debuginfo-windows-x64-5.15.17.jar: sources/QtJambiWebEngineCore/QWebEngineCookieStore_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtWebEngineCore/qwebenginecookiestore.h>
#include <QtCore/QVariant>
#include <QtNetwork/qnetworkcookie.h>
#include <QtCore/qurl.h>
#include <QtCore/qobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/QList>
#include <QtCore/qcoreevent.h>
#include <QtCore/qtimer.h>
#include <QtCore/qregexp.h>
#include <QtCore/qthread.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qmetaobject.h>
#include <QtCore/qbytearray.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/JavaAPI>
#include <QtJambi/JObjectWrapper>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

int __signal_method_indexes_QWebEngineCookieStore_0(){
    static int result = QMetaMethod::fromSignal(&QWebEngineCookieStore::cookieAdded).methodIndex();
    return result;
}


int __signal_method_indexes_QWebEngineCookieStore_1(){
    static int result = QMetaMethod::fromSignal(&QWebEngineCookieStore::cookieRemoved).methodIndex();
    return result;
}


// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineCookieStore::deleteAllCookies()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineCookieStore_deleteAllCookies_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineCookieStore *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineCookieStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineCookieStore::deleteAllCookies()", __qt_this)
        __qt_this->deleteAllCookies();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineCookieStore::deleteCookie(QNetworkCookie,QUrl)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineCookieStore_deleteCookie_1native_1cref_1QNetworkCookie_1cref_1QUrl__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID cookie0,
 QtJambiNativeID origin1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineCookieStore *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineCookieStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineCookieStore::deleteCookie(QNetworkCookie,QUrl)", __qt_this)
        const QNetworkCookie& __qt_cookie0 = QtJambiAPI::valueReferenceFromNativeId<QNetworkCookie>(cookie0);
        const QUrl& __qt_origin1 = QtJambiAPI::valueReferenceFromNativeId<QUrl>(origin1);
        __qt_this->deleteCookie(__qt_cookie0, __qt_origin1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineCookieStore::deleteSessionCookies()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineCookieStore_deleteSessionCookies_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineCookieStore *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineCookieStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineCookieStore::deleteSessionCookies()", __qt_this)
        __qt_this->deleteSessionCookies();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineCookieStore::loadAllCookies()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineCookieStore_loadAllCookies_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineCookieStore *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineCookieStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineCookieStore::loadAllCookies()", __qt_this)
        __qt_this->loadAllCookies();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineCookieStore::setCookie(QNetworkCookie,QUrl)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineCookieStore_setCookie_1native_1cref_1QNetworkCookie_1cref_1QUrl__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID cookie0,
 QtJambiNativeID origin1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineCookieStore *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineCookieStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineCookieStore::setCookie(QNetworkCookie,QUrl)", __qt_this)
        const QNetworkCookie& __qt_cookie0 = QtJambiAPI::valueReferenceFromNativeId<QNetworkCookie>(cookie0);
        const QUrl& __qt_origin1 = QtJambiAPI::valueReferenceFromNativeId<QUrl>(origin1);
        __qt_this->setCookie(__qt_cookie0, __qt_origin1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineCookieStore::setCookieFilter(const std::function<bool(const QWebEngineCookieStore::FilterRequest&)>&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineCookieStore_setCookieFilter_1native_1cref_1std_1function_1bool_1const_1QWebEngineCookieStore_1FilterRequest_1ref_1_1__JLjava_util_function_Predicate_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject filterCallback0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineCookieStore *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineCookieStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineCookieStore::setCookieFilter(const std::function<bool(const QWebEngineCookieStore::FilterRequest&)>&)", __qt_this)
        std::function<bool(const QWebEngineCookieStore::FilterRequest &)> __qt_filterCallback0;
        if(filterCallback0){
            JObjectWrapper wrapper(__jni_env, filterCallback0);
            __qt_filterCallback0 = [wrapper](const QWebEngineCookieStore::FilterRequest & value) -> bool {
                                if(JniEnvironment env{200}){
                                    jobject _value = qtjambi_cast<jobject>(env, value);
                                    return Java::Runtime::Predicate::test(env, wrapper.object(), _value);
                                }
                            return false;
                        };
                    }
        __qt_this->setCookieFilter(__qt_filterCallback0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

bool javaToNativeConverter_QNetworkCookie_cref(JNIEnv*, QtJambiScope*, jvalue, void* &, jValueType);
bool javaToNativeConverter_QNetworkCookie_cref(JNIEnv*, QtJambiScope*, jvalue, void* &, jValueType); // declared in QWebEngineCookieStore
bool nativeToJavaConverter_QNetworkCookie_cref(JNIEnv*, QtJambiScope*, const void*, jvalue&, bool);
bool nativeToJavaConverter_QNetworkCookie_cref(JNIEnv*, QtJambiScope*, const void*, jvalue&, bool); // declared in QWebEngineCookieStore

bool javaToNativeConverter_QNetworkCookie_cref(JNIEnv* env, QtJambiScope* scope, jvalue in, void* &out, jValueType) {
    Q_UNUSED(env)
    Q_UNUSED(scope)
    if(out){
        *reinterpret_cast<QNetworkCookie*>(out) = qtjambi_cast<const QNetworkCookie& >(env, in.l);
    }else{
        out = const_cast<QNetworkCookie*>(&qtjambi_cast<const QNetworkCookie& >(env, in.l));
    }
    return true;
}

bool nativeToJavaConverter_QNetworkCookie_cref(JNIEnv* env, QtJambiScope* scope, const void* in, jvalue& out, bool) {
    Q_UNUSED(env)
    Q_UNUSED(scope)
    out.l = qtjambi_cast<jobject>(env, *reinterpret_cast<QNetworkCookie const*>(in));
    return true;
}


void initialize_meta_info_QWebEngineCookieStore(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QWebEngineCookieStore>("QWebEngineCookieStore", "io/qt/webengine/core/QWebEngineCookieStore");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QWebEngineCookieStore::staticMetaObject, false,
            {
                SignalMetaInfo(/* 0 */ "cookieAdded", "Lio/qt/core/QObject$Signal1;", 1, __signal_method_indexes_QWebEngineCookieStore_0),
                SignalMetaInfo(/* 1 */ "cookieRemoved", "Lio/qt/core/QObject$Signal1;", 1, __signal_method_indexes_QWebEngineCookieStore_1)
            },
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==__signal_method_indexes_QWebEngineCookieStore_0()){ // cookieAdded(const QNetworkCookie & cookie)
                    infos << ParameterInfo(QMetaType::Void);
                    infos << ParameterInfo(
                                // const QNetworkCookie&
                                method.parameterType(0),
                                "io/qt/network/QNetworkCookie",
                                &nativeToJavaConverter_QNetworkCookie_cref,
                                &javaToNativeConverter_QNetworkCookie_cref);
                    return true;
                }
                if(methodIndex==__signal_method_indexes_QWebEngineCookieStore_1()){ // cookieRemoved(const QNetworkCookie & cookie)
                    infos << ParameterInfo(QMetaType::Void);
                    infos << ParameterInfo(
                                // const QNetworkCookie&
                                method.parameterType(0),
                                "io/qt/network/QNetworkCookie",
                                &nativeToJavaConverter_QNetworkCookie_cref,
                                &javaToNativeConverter_QNetworkCookie_cref);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-webenginecore-debuginfo-windows-x64-6.5.5.jar: sources/QtJambiWebEngineCore/QWebEngineCookieStore_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebEngineCore/qwebenginecookiestore.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtNetwork/qnetworkcookie.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/JObjectWrapper>
#include <QtJambi/JavaAPI>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

int __signal_method_indexes_QWebEngineCookieStore_0(){
    static int result = QMetaMethod::fromSignal(&QWebEngineCookieStore::cookieAdded).methodIndex();
    return result;
}


int __signal_method_indexes_QWebEngineCookieStore_1(){
    static int result = QMetaMethod::fromSignal(&QWebEngineCookieStore::cookieRemoved).methodIndex();
    return result;
}


// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineCookieStore::deleteAllCookies()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineCookieStore_deleteAllCookies_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineCookieStore *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineCookieStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineCookieStore::deleteAllCookies()", __qt_this)
        __qt_this->deleteAllCookies();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineCookieStore::deleteCookie(QNetworkCookie,QUrl)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineCookieStore_deleteCookie_1native_1cref_1QNetworkCookie_1cref_1QUrl__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID cookie0,
 QtJambiNativeID origin1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineCookieStore *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineCookieStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineCookieStore::deleteCookie(QNetworkCookie,QUrl)", __qt_this)
        const QNetworkCookie& __qt_cookie0 = QtJambiAPI::valueReferenceFromNativeId<QNetworkCookie>(cookie0);
        const QUrl& __qt_origin1 = QtJambiAPI::valueReferenceFromNativeId<QUrl>(origin1);
        __qt_this->deleteCookie(__qt_cookie0, __qt_origin1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineCookieStore::deleteSessionCookies()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineCookieStore_deleteSessionCookies_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineCookieStore *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineCookieStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineCookieStore::deleteSessionCookies()", __qt_this)
        __qt_this->deleteSessionCookies();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineCookieStore::loadAllCookies()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineCookieStore_loadAllCookies_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineCookieStore *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineCookieStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineCookieStore::loadAllCookies()", __qt_this)
        __qt_this->loadAllCookies();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineCookieStore::setCookie(QNetworkCookie,QUrl)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineCookieStore_setCookie_1native_1cref_1QNetworkCookie_1cref_1QUrl__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID cookie0,
 QtJambiNativeID origin1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineCookieStore *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineCookieStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineCookieStore::setCookie(QNetworkCookie,QUrl)", __qt_this)
        const QNetworkCookie& __qt_cookie0 = QtJambiAPI::valueReferenceFromNativeId<QNetworkCookie>(cookie0);
        const QUrl& __qt_origin1 = QtJambiAPI::valueReferenceFromNativeId<QUrl>(origin1);
        __qt_this->setCookie(__qt_cookie0, __qt_origin1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineCookieStore::setCookieFilter(const std::function<bool(const QWebEngineCookieStore::FilterRequest&)>&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineCookieStore_setCookieFilter_1native_1cref_1std_1function_1bool_1const_1QWebEngineCookieStore_1FilterRequest_1ref_1_1__JLjava_util_function_Predicate_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject filterCallback0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineCookieStore *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineCookieStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineCookieStore::setCookieFilter(const std::function<bool(const QWebEngineCookieStore::FilterRequest&)>&)", __qt_this)
        std::function<bool(const QWebEngineCookieStore::FilterRequest &)> __qt_filterCallback0;
        if(filterCallback0){
            JObjectWrapper wrapper(__jni_env, filterCallback0);
            __qt_filterCallback0 = [wrapper](const QWebEngineCookieStore::FilterRequest & value) -> bool {
                                if(JniEnvironment env{200}){
                                    jobject _value = qtjambi_cast<jobject>(env, value);
                                    return Java::Runtime::Predicate::test(env, wrapper.object(), _value);
                                }
                            return false;
                        };
                    }
        __qt_this->setCookieFilter(__qt_filterCallback0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

bool javaToNativeConverter_QNetworkCookie_cref(JNIEnv*, QtJambiScope*, jvalue, void* &, jValueType);
bool javaToNativeConverter_QNetworkCookie_cref(JNIEnv*, QtJambiScope*, jvalue, void* &, jValueType); // declared in QWebEngineCookieStore
bool nativeToJavaConverter_QNetworkCookie_cref(JNIEnv*, QtJambiScope*, const void*, jvalue&, bool);
bool nativeToJavaConverter_QNetworkCookie_cref(JNIEnv*, QtJambiScope*, const void*, jvalue&, bool); // declared in QWebEngineCookieStore

bool javaToNativeConverter_QNetworkCookie_cref(JNIEnv* env, QtJambiScope* scope, jvalue in, void* &out, jValueType) {
    Q_UNUSED(env)
    Q_UNUSED(scope)
    if(out){
        *reinterpret_cast<QNetworkCookie*>(out) = qtjambi_cast<const QNetworkCookie& >(env, in.l);
    }else{
        out = const_cast<QNetworkCookie*>(&qtjambi_cast<const QNetworkCookie& >(env, in.l));
    }
    return true;
}

bool nativeToJavaConverter_QNetworkCookie_cref(JNIEnv* env, QtJambiScope* scope, const void* in, jvalue& out, bool) {
    Q_UNUSED(env)
    Q_UNUSED(scope)
    out.l = qtjambi_cast<jobject>(env, *reinterpret_cast<QNetworkCookie const*>(in));
    return true;
}


void initialize_meta_info_QWebEngineCookieStore(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QWebEngineCookieStore>("QWebEngineCookieStore", "io/qt/webengine/core/QWebEngineCookieStore");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QWebEngineCookieStore::staticMetaObject, false,
            {
                SignalMetaInfo(/* 0 */ "cookieAdded", "Lio/qt/core/QObject$Signal1;", 1, __signal_method_indexes_QWebEngineCookieStore_0),
                SignalMetaInfo(/* 1 */ "cookieRemoved", "Lio/qt/core/QObject$Signal1;", 1, __signal_method_indexes_QWebEngineCookieStore_1)
            },
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==__signal_method_indexes_QWebEngineCookieStore_0()){ // cookieAdded(const QNetworkCookie & cookie)
                    infos << ParameterInfo(QMetaType::Void);
                    infos << ParameterInfo(
                                // const QNetworkCookie&
                                method.parameterType(0),
                                "io/qt/network/QNetworkCookie",
                                &nativeToJavaConverter_QNetworkCookie_cref,
                                &javaToNativeConverter_QNetworkCookie_cref);
                    return true;
                }
                if(methodIndex==__signal_method_indexes_QWebEngineCookieStore_1()){ // cookieRemoved(const QNetworkCookie & cookie)
                    infos << ParameterInfo(QMetaType::Void);
                    infos << ParameterInfo(
                                // const QNetworkCookie&
                                method.parameterType(0),
                                "io/qt/network/QNetworkCookie",
                                &nativeToJavaConverter_QNetworkCookie_cref,
                                &javaToNativeConverter_QNetworkCookie_cref);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
